@@ -33,8 +33,10 @@ checkList <- function(passedList, defaultList, label = "'algo'") {
 
 ##
 
-mRU <- function(m, n) array(runif(m*n), dim = c(m,n))
-mRN <- function(m, n) array(rnorm(m*n), dim = c(m,n))
+mRU <- function(m, n)
+    array(runif(m*n), dim = c(m,n))
+mRN <- function(m, n)
+    array(rnorm(m*n), dim = c(m,n))
 
 ##
 
@@ -46,3 +48,31 @@ mcList <- function(mc.control) {
     mc.settings[names(mc.control)] <- mc.control
     mc.settings
 }
+
+##
+
+repair1c <- function(x, up, lo) {
+    xadjU <- x - up
+    xadjU <- xadjU + abs(xadjU)
+    xadjL <- lo - x
+    xadjL <- xadjL + abs(xadjL)
+    x - (xadjU - xadjL)/2
+}
+
+##
+
+Chapters <- c("Introduction",
+              "Numerical analysis in a nutshell",
+              "Linear equations and Least Squares problems",
+              "Finite difference methods",
+              "Binomial trees",
+              "Generating random numbers",
+              "Modeling dependencies",
+              "A gentle introduction to financial simulation",
+              "Financial simulation at work: some case studies",
+              "Optimization problems in finance",
+              "Basic methods",
+              "Heuristic methods in a nutshell",
+              "Portfolio optimization",
+              "Econometric models",
+              "Calibrating option pricing models")
